==> huaweicloudsdkiotda-3.0.5b0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/list_commands_response.py <==
# coding: utf-8

import pprint
import re

import six


class ListCommandsResponse(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'device_id': 'str',
        'commands': 'list[DeviceCommandV5]'
    }

    attribute_map = {
        'device_id': 'device_id',
        'commands': 'commands'
    }

    def __init__(self, device_id=None, commands=None):  # noqa: E501
        """ListCommandsResponse - a model defined in huaweicloud sdk"""

        self._device_id = None
        self._commands = None
        self.discriminator = None

        if device_id is not None:
            self.device_id = device_id
        if commands is not None:
            self.commands = commands

    @property
    def device_id(self):
        """Gets the device_id of this ListCommandsResponse.

        设备ID，用于唯一标识一个设备，在注册设备时由物联网平台分配获得。

        :return: The device_id of this ListCommandsResponse.
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this ListCommandsResponse.

        设备ID，用于唯一标识一个设备，在注册设备时由物联网平台分配获得。

        :param device_id: The device_id of this ListCommandsResponse.
        :type: str
        """
        self._device_id = device_id

    @property
    def commands(self):
        """Gets the commands of this ListCommandsResponse.

        设备命令列表。

        :return: The commands of this ListCommandsResponse.
        :rtype: list[DeviceCommandV5]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this ListCommandsResponse.

        设备命令列表。

        :param commands: The commands of this ListCommandsResponse.
        :type: list[DeviceCommandV5]
        """
        self._commands = commands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCommandsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.0.7b0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/list_commands_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListCommandsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'device_id': 'str',
        'commands': 'list[DeviceCommandV5]'
    }

    attribute_map = {
        'device_id': 'device_id',
        'commands': 'commands'
    }

    def __init__(self, device_id=None, commands=None):
        """ListCommandsResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._device_id = None
        self._commands = None
        self.discriminator = None

        if device_id is not None:
            self.device_id = device_id
        if commands is not None:
            self.commands = commands

    @property
    def device_id(self):
        """Gets the device_id of this ListCommandsResponse.

        设备ID，用于唯一标识一个设备，在注册设备时由物联网平台分配获得。

        :return: The device_id of this ListCommandsResponse.
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this ListCommandsResponse.

        设备ID，用于唯一标识一个设备，在注册设备时由物联网平台分配获得。

        :param device_id: The device_id of this ListCommandsResponse.
        :type: str
        """
        self._device_id = device_id

    @property
    def commands(self):
        """Gets the commands of this ListCommandsResponse.

        设备命令列表。

        :return: The commands of this ListCommandsResponse.
        :rtype: list[DeviceCommandV5]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this ListCommandsResponse.

        设备命令列表。

        :param commands: The commands of this ListCommandsResponse.
        :type: list[DeviceCommandV5]
        """
        self._commands = commands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCommandsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
